| Title: | Creates a Prisma Diagram using DiagrammeR |
|---|---|
| Description: | Creates PRISMA <http://prisma-statement.org/> diagram from a minimal dataset of included and excluded studies and allows for more custom diagrams. PRISMA diagrams are used to track the identification, screening, eligibility, and inclusion of studies in a systematic review. |
| Authors: | Lionel Duarte [aut, cre] (ORCID: <https://orcid.org/0000-0003-0296-4949>) |
| Maintainer: | Lionel Duarte <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-22 18:51:10 UTC |
| Source: | https://github.com/ltrainstg/prismadiagramr |
Create Prisma These functions create a PRISMA diagram from a simple dataframe keeping track of sources and filters It creates a DiagrammeR file run by grV
getPrisma(studyStatus = NULL, prismaFormat = NULL)getPrisma(studyStatus = NULL, prismaFormat = NULL)
studyStatus |
a dataframe that keeps track of |
prismaFormat |
how large to make the characters in the diagram |
prismaTemplate A text file use to make a PRISMA diagram.
prismaTemplate <- getPrisma(studyStatus) prismaFormat <- getPrismaFormat(studyStatus) prismaTemplate <- getPrisma(studyStatus, prismaFormat) DiagrammeR::grViz(prismaTemplate)prismaTemplate <- getPrisma(studyStatus) prismaFormat <- getPrismaFormat(studyStatus) prismaTemplate <- getPrisma(studyStatus, prismaFormat) DiagrammeR::grViz(prismaTemplate)
Create Prisma These functions create a PRISMA diagram from a simple dataframe keeping track of sources and filters It creates a DiagrammeR file run by grV
getPrismaFormat(studyStatus)getPrismaFormat(studyStatus)
studyStatus |
a dataframe that keeps track of studies used. |
prismaFormat A dataframe with information on how to make a PRISMA diagram.
prismaTemplate <- getPrisma(studyStatus) prismaFormat <- getPrismaFormat(studyStatus) prismaTemplate <- getPrisma(studyStatus, prismaFormat) DiagrammeR::grViz(prismaTemplate)prismaTemplate <- getPrisma(studyStatus) prismaFormat <- getPrismaFormat(studyStatus) prismaTemplate <- getPrisma(studyStatus, prismaFormat) DiagrammeR::grViz(prismaTemplate)
A dataset containing one row per entry in the PRISMA diagram.
studyStatusstudyStatus
A data frame with 10 rows and 4 variables:
Pubblication unique identifier
Source identifier
Filter identifier